#
# spec file for package python-wadllib
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-wadllib
Version:        2.0.0
Release:        1.2
Summary:        Navigate HTTP resources using WADL files as guides
License:        LGPL-3.0-or-later
URL:            https://launchpad.net/wadllib
Source:         https://files.pythonhosted.org/packages/source/w/wadllib/wadllib-%{version}.tar.gz
BuildRequires:  %{python_module lazr.uri}
BuildRequires:  %{python_module multipart}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-lazr.uri
BuildArch:      noarch
%python_subpackages

%description
An Application object represents a web service described by a WADL
file.

%prep
%setup -q -n wadllib-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
# Do not ship docs
%python_expand rm -r %{buildroot}%{$python_sitelib}/wadllib/docs
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
cd src
%pyunittest discover -v

%files %{python_files}
%license COPYING.txt
%doc README.rst NEWS.rst
%{python_sitelib}/wadllib
%{python_sitelib}/wadllib-%{version}.dist-info

%changelog
* Fri Nov 15 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 2.0.0:
  * Drop support for Python < 3.8.
  * legacy-cgi is only a test dependency. Make it an optional dependency.
  * Add support for Python 3.11-3.13.
  * Add support for Python 3.9 and 3.10.
- Switch to pyproject macros.
- No more greedy globs in %%files.
* Sun Oct 24 2021 Matej Cepl <mcepl@suse.com>
- Update to 1.3.6:
  - Remove buildout support in favour of tox. [bug=922605]
  - Adjust versioning strategy to avoid importing pkg_resources,
    which is slow in large environments.
* Tue Aug 17 2021 pgajdos@suse.com
- version update to 1.3.5
  - Drop support for Python 3.2, 3.3, and 3.4.
  - Accept Unicode parameter values again when performing multipart/form-data
    encoding on Python 2 (broken in 1.3.3).
- %%check: use %%pyunittest rpm macro
* Wed Jul 22 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 1.3.4
  * Advertise support for Python 3.8.
  * Add Python 3.9 compatibility by using xml.etree.ElementTree if
    xml.etree.cElementTree does not exist.  [bug=1870294]
* Thu Aug 23 2018 tchvatal@suse.com
- Update to 1.3.3:
  * Support python3
- Switch to singlespec
- Run tests
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Wed Mar 20 2013 speilicke@suse.com
- Add COPYING.txt
* Fri Mar 15 2013 speilicke@suse.com
- Initial version
